def pytest_configure():
    """Configures pytest for Django-aware testing"""
    from django.conf import settings

    settings.configure(
        AFFIRMATIVE = 'ok',

        DATABASES = {
            'default': {
                'ENGINE': 'django.db.backends.sqlite3',
                'NAME': ':memory:'
            },
        },

        SECRET_KEY = 'sssshhhhhh',
        USE_TZ = True,

        ROOT_URLCONF = 'tests.urls',

        INSTALLED_APPS=(
            'django.contrib.auth',
            'django.contrib.contenttypes',
            'django.contrib.sessions',
            'django.contrib.sites',
            'django.contrib.messages',

            'active_login_required',
            'tests',
        ),

        MIDDLEWARE_CLASSES = (
            'django.middleware.common.CommonMiddleware',
            'django.contrib.sessions.middleware.SessionMiddleware',
            'django.middleware.csrf.CsrfViewMiddleware',
            'django.contrib.auth.middleware.AuthenticationMiddleware',
            'django.contrib.messages.middleware.MessageMiddleware',
        ),
    )

    try:
        import django
        django.setup()
    except AttributeError:
        pass



from __future__ import unicode_literals

from django.conf import settings
from django.contrib.auth.models import User
from django.test import Client, TestCase


class UserTestCase(TestCase):
    def setUp(self):
        self.client = Client()

        self.password = '...'

        # create an active user
        self.active_user = User(username='active_user', is_active=True)
        self.active_user.set_password(self.password)
        self.active_user.save()

        # create an inactive user
        self.inactive_user = User(username='inactive_user', is_active=False)
        self.inactive_user.set_password(self.password)
        self.inactive_user.save()

    def test_anonymous_user_redirection(self):
        expected_url = '/accounts/login/?next=/test_view_a/'

        resp = self.client.get('/test_view_a/')

        self.assertRedirects(resp, expected_url,
                             fetch_redirect_response=False)

    def test_inactive_user(self):
        expected_url = '/accounts/login/?next=/test_view_a/'

        self.client.login(username=self.inactive_user,
                          password=self.password)

        resp = self.client.get('/test_view_a/')

        self.assertRedirects(resp, expected_url,
                             fetch_redirect_response=False)

    def test_active_user(self):
        self.client.login(username=self.active_user,
                          password=self.password)

        resp = self.client.get('/test_view_a/')
        self.assertEqual(resp.status_code, 200)
        self.assertEqual(resp.content, settings.AFFIRMATIVE)



from __future__ import unicode_literals

from django.contrib.auth import REDIRECT_FIELD_NAME
from django.contrib.auth.decorators import user_passes_test


__all__ = ('active_login_required', )


def active_login_required(function=None,
                          redirect_field_name=REDIRECT_FIELD_NAME,
                          login_url=None):
    """Ensures that a user meets two qualifications:

    1. The user is authenticated
    2. The user is active

    Deactivating a user does not disable their session.
    (Remember that sessions aren't tied to users).
    """

    actual_decorator = user_passes_test(
        test_func=lambda u: u.is_authenticated() and u.is_active,
        login_url=login_url,
        redirect_field_name=redirect_field_name
    )

    if function:
        return actual_decorator(function)

    return actual_decorator



import os
from setuptools import setup, find_packages

# dependencies: Django, collection, itertools, autoslug

setup(
    name='django-active-login-required',
    version='0.1.1',
    description='',
    author='Matt Dennewitz',
    author_email='mattdennewitz@gmail.com',
    url='http://github.com/mattdennewitz/django-active-login-required',
    packages=find_packages(),
    install_requires=['django >= 1.6'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Framework :: Django',
    ],
)



from __future__ import unicode_literals

from django.conf import settings
from django.http import HttpResponse
from django.shortcuts import render

from active_login_required import active_login_required


@active_login_required
def test_view_a(request):
    return HttpResponse(settings.AFFIRMATIVE)
